@@ -339,6 +339,21 @@ class AsyncClient(BaseClient):
     async def time(self):
         return await self._request_public_api(path="time")
 
+    async def mark_price(self, instType: InstType = None, uly=None, instId=None):
+        """
+        获取标记价格
+        instType	String	是	产品类型
+                                MARGIN：币币杠杆
+                                SWAP：永续合约
+                                FUTURES：交割合约
+                                OPTION：期权
+        uly	String	否	合约标的指数
+        instId	String	否	产品ID，如 BTC-USD-SWAP
+        """
+        assert instType in (InstType.SWAP, InstType.FUTURES, InstType.OPTION, InstType.MARGIN)
+        params = package_data(remove_key(locals()))
+        return await self._request_public_api(path="mark-price", params=params)
+
     async def underlying(self, instType: InstType):
         """
         获取合约衍生品标的指数
